bluemath\_tk.distributions package
==================================

Submodules
----------

bluemath\_tk.distributions.copula module
----------------------------------------

.. automodule:: bluemath_tk.distributions.copula
   :members:
   :undoc-members:
   :show-inheritance:

bluemath\_tk.distributions.gev module
-------------------------------------

.. automodule:: bluemath_tk.distributions.gev
   :members:
   :undoc-members:
   :show-inheritance:

bluemath\_tk.distributions.gpd module
-------------------------------------

.. automodule:: bluemath_tk.distributions.gpd
   :members:
   :undoc-members:
   :show-inheritance:

bluemath\_tk.distributions.poisson module
-----------------------------------------

.. automodule:: bluemath_tk.distributions.poisson
   :members:
   :undoc-members:
   :show-inheritance:

bluemath\_tk.distributions.pot module
-------------------------------------

.. automodule:: bluemath_tk.distributions.pot
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: bluemath_tk.distributions
   :members:
   :undoc-members:
   :show-inheritance:
